Index: /issm/trunk/scripts/archive.sh
===================================================================
--- /issm/trunk/scripts/archive.sh	(revision 2618)
+++ /issm/trunk/scripts/archive.sh	(revision 2619)
@@ -2,7 +2,4 @@
 #This bash routine  will create a tar file for the ISSM
 #code. Just run the following command: 
-
-#> source  ./archive.sh
-
 
 #Some local script functions 
@@ -12,19 +9,14 @@
 }
 
-#Main 
-
 #Cleanup code 
 cd $ISSM_DIR
-make -f MakefileIce clean
 make clean
 make distclean
 
-#Get rid of packages
-rm packages
-
-cd $ISSM_DIR/..
+#Get rid of externalpackages
+rm -rf externalpackages
 
 #Create tar file, with today's date in the title;
+cd $ISSM_DIR/..
 today=`today_date`
-
-tar zcvf issm-1.0-$today.tar.gz  `basename $ISSM_DIR`
+tar zcvf issm-3.0-$today.tar.gz  `basename $ISSM_DIR`
